@@ -1,7 +1,7 @@
 #! /usr/bin/perl
 
 # ex:ts=8 sw=4:
-# $OpenBSD: Quirks.pm,v 1.1257 2021/04/07 11:43:12 sthen Exp $
+# $OpenBSD: Quirks.pm,v 1.1257.2.1 2021/05/21 17:52:42 bket Exp $
 #
 # Copyright (c) 2009 Marc Espie <espie@openbsd.org>
 #
@@ -2449,6 +2449,7 @@ my $cve = {
 	'archivers/brotli' => 'brotli-<1.0.9',
 	'archivers/cabextract' => 'cabextract-<1.8',
 	'archivers/libmspack' => 'libmspack-<0.8alpha',
+	'archivers/lz4' => 'lz4-<1.9.3p0',
 	'archivers/p5-Archive-Zip' => 'p5-Archive-Zip-<1.64',
 	'audio/flac' => 'flac-<1.3.0p1',
 	'databases/mariadb,-main' => 'mariadb-client-<10.3.22',
